.. pymopac documentation master file, created by
   sphinx-quickstart on Sun Jun 23 14:47:07 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pymopac's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README
   pymopac



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
